@@ -5,7 +5,7 @@ from flask import Flask
 from flask_apscheduler import APScheduler
 from flask_sqlalchemy import SQLAlchemy
 from notejob.center.app.CuBackgroundScheduler import CuBackgroundScheduler
-from notejob.center.config import Config, config_dict
+from notejob.center.config import config_dict
 
 scheduler = APScheduler(scheduler=CuBackgroundScheduler())
 
@@ -23,7 +23,7 @@ def create_app(config_name):
 
     logging.basicConfig(level=logging.ERROR)
 
-    info_handler = TimedRotatingFileHandler("%s/datas/logs/info.log" % config[config_name].BASEDIR,
+    info_handler = TimedRotatingFileHandler("%s/datas/logs/info.log" % config.BASEDIR,
                                             when="H",
                                             interval=1, backupCount=7, encoding="UTF-8", delay=False,
                                             utc=True)
@@ -33,7 +33,7 @@ def create_app(config_name):
 
     app.logger.addHandler(info_handler)
 
-    error_handler = TimedRotatingFileHandler("%s/datas/logs/error.log" % config[config_name].BASEDIR,
+    error_handler = TimedRotatingFileHandler("%s/datas/logs/error.log" % config.BASEDIR,
                                              when="D",
                                              interval=1, backupCount=15, encoding="UTF-8", delay=False,
                                              utc=True)
