@@ -12,11 +12,11 @@ from notejob.center.datas.model.job_log import JobLog
 from notejob.center.datas.model.job_log_items import JobLogItems
 from notejob.center.datas.utils.times import get_now_time
 
-from . import main
 
+from.core import blue_print
 
-@main.route('/cron_list', methods=['GET', 'POST'])
-@main.route('/', methods=['GET', 'POST'])
+@blue_print.route('/cron_list', methods=['GET', 'POST'])
+@blue_print.route('/', methods=['GET', 'POST'])
 @login_required
 def cron_list():
     keyword = request.args.to_dict()
@@ -33,13 +33,13 @@ def cron_list():
     return render_template("cron_list.html", page_data=page_data, keyword=keyword)
 
 
-@main.route('/api_doc', methods=['GET', 'POST'])
+@blue_print.route('/api_doc', methods=['GET', 'POST'])
 @login_required
 def api_doc():
     return render_template("api_doc.html")
 
 
-@main.route('/job_log_list', methods=['GET', 'POST'])
+@blue_print.route('/job_log_list', methods=['GET', 'POST'])
 @login_required
 def job_log_list():
     keywords = request.args.to_dict()
@@ -57,7 +57,7 @@ def job_log_list():
     return render_template("job_log_list.html", page_data=page_data, keywords=keywords)
 
 
-@main.route('/job_log_item_list', methods=['GET', 'POST'])
+@blue_print.route('/job_log_item_list', methods=['GET', 'POST'])
 @login_required
 def job_log_item_list():
     log_id = request.args.get('log_id')
@@ -66,7 +66,7 @@ def job_log_item_list():
     return render_template("job_log_item_list.html", page_data=page_data)
 
 
-@main.route('/job_log_all_list', methods=['GET', 'POST'])
+@blue_print.route('/job_log_all_list', methods=['GET', 'POST'])
 @login_required
 def job_log_all_list():
     keywords = request.args.to_dict()
@@ -95,7 +95,7 @@ def job_log_all_list():
     return render_template("job_log_all_list.html", page_data=page_data, keywords=keywords)
 
 
-@main.route('/job_log_delete', methods=['GET', 'POST'])
+@blue_print.route('/job_log_delete', methods=['GET', 'POST'])
 @login_required
 def job_log_delete():
     datas = request.values.to_dict()
@@ -109,7 +109,7 @@ def job_log_delete():
     return web_api_return(code=0, msg='删除成功')
 
 
-@main.route('/job_batch_delete', methods=['GET', 'POST'])
+@blue_print.route('/job_batch_delete', methods=['GET', 'POST'])
 @login_required
 def job_batch_delete():
     ids = request.form.getlist('id')
@@ -118,7 +118,7 @@ def job_batch_delete():
     return web_api_return(code=0, msg='操作成功', url='/job_log_all_list')
 
 
-@main.route('/cron_add', methods=['GET', 'POST'])
+@blue_print.route('/cron_add', methods=['GET', 'POST'])
 @login_required
 def cron_add():
     if request.method == 'POST':
@@ -226,7 +226,7 @@ def cron_add():
     return render_template("cron_add.html")
 
 
-@main.route('/cron_edit', methods=['GET', 'POST'])
+@blue_print.route('/cron_edit', methods=['GET', 'POST'])
 @login_required
 def cron_edit():
     id = request.values.get('id')
@@ -347,7 +347,7 @@ def cron_edit():
     return render_template("cron_edit.html", cif=cif)
 
 
-@main.route('/update_status', methods=['GET', 'POST'])
+@blue_print.route('/update_status', methods=['GET', 'POST'])
 @login_required
 def update_status():
     id = request.args.get('id')
@@ -367,7 +367,7 @@ def update_status():
     return web_api_return(code=0, msg='操作成功')
 
 
-@main.route('/cron_del', methods=['GET', 'POST'])
+@blue_print.route('/cron_del', methods=['GET', 'POST'])
 @login_required
 def cron_del():
     id = request.args.get('id')
@@ -389,7 +389,7 @@ def cron_del():
     return web_api_return(code=0, msg='操作成功', url='/cron_list')
 
 
-@main.route('/cron_batch_del', methods=['GET', 'POST'])
+@blue_print.route('/cron_batch_del', methods=['GET', 'POST'])
 @login_required
 def cron_batch_del():
     ids = request.form.getlist('id')
@@ -406,7 +406,7 @@ def cron_batch_del():
     return web_api_return(code=0, msg='操作成功', url='/cron_list')
 
 
-@main.route('/check_pass', methods=['GET', 'POST'])
+@blue_print.route('/check_pass', methods=['GET', 'POST'])
 def check_pass():
     today = get_now_time()
     msg = request.values.get('msg', '')
@@ -428,7 +428,7 @@ def check_pass():
     return render_template("check_pass.html", msg=msg, today=today)
 
 
-@main.route('/logout')
+@blue_print.route('/logout')
 def logout():
     session.clear()
     return redirect("/check_pass")
